# DO NOT EDIT THIS FILE, IT IS GENERATED BY SETUP.PY
__version__ = "0.0.1"
package_name = "geoview"
git_branch = "tzx/0206"
git_commit_hash = "8895c28"
git_commit_date = "2023/02/06 23:43:10"
git_commit_count = 2
git_diff_name_only = ""
doc_url = "TODO"
repo_url = "https://github.com/cubao/geoview"
