# DO NOT EDIT THIS FILE, IT IS GENERATED BY SETUP.PY
__version__ = "0.0.1"
package_name = "geoview"
git_branch = "main"
git_commit_hash = "e941031"
git_commit_date = "2023/02/06 23:51:23"
git_commit_count = 2
git_diff_name_only = "setup.py"
doc_url = "https://pypi.org/project/geoview"
repo_url = "https://github.com/cubao/geoview"
